@@ -1,27 +1,13 @@
 # -*- coding: utf-8 -*-
-# author:chao.yy
-# email:yuyc@ishangqi.com
-# date:2021/12/8 10:53 上午
-# Copyright (C) 2021 The lesscode Team
 import json
 import logging
 import os
-import random
 import traceback
 from datetime import datetime
 
-import requests
-from requests.auth import HTTPBasicAuth
 from tornado.options import options
 
-from lesscode.db.base_sql_helper import BaseSqlHelper, echo_sql
-from lesscode.db.condition_wrapper import ConditionWrapper
-from lesscode.db.connection_info import ConnectionInfo
-from lesscode.db.es.es_pool import EsPool
-from lesscode.db.es.es_request import EsRequest
-from lesscode.db.page import Page
-from lesscode.utils.EsUtil import format_es_param_result, es_mapping2dict
-from lesscode.utils.common import dict2single_dict
+from lesscode.utils.EsUtil import format_es_param_result
 from lesscode.utils.encryption_algorithm import AES
 
 
