@@ -1,10 +1,19 @@
 # -*- coding: utf-8 -*-
-# author:chao.yy
-# email:yuyc@ishangqi.com
-# date:2022/2/17 2:45 下午
-# Copyright (C) 2022 The lesscode Team
+import importlib
+
 from lesscode.db.base_connection_pool import BaseConnectionPool
-from pymongo import MongoClient
+
+pymongo = None
+motor = None
+try:
+    pymongo = importlib.import_module("pymongo")
+except ImportError as e:
+    raise Exception(f"pymongo is not exist,run:pip install pymongo==3.12.3")
+
+try:
+    motor = importlib.import_module("motor")
+except ImportError as e:
+    raise Exception(f"motor is not exist,run:pip install motor==2.5.1")
 
 
 class MongodbPool(BaseConnectionPool):
@@ -21,7 +30,6 @@ class MongodbPool(BaseConnectionPool):
         """
         info = self.conn_info
         if info.async_enable:
-            import motor
             host_str = info.host.split(",")
             hosts = ",".join([f"{host}:{info.port}" for host in host_str])
             conn_info_string = f"mongodb://{info.user}:{info.password}@{hosts}"
@@ -49,5 +57,5 @@ class MongodbPool(BaseConnectionPool):
                 conn_info_string += "/?authSource=admin"
             elif info.params == "X509":
                 conn_info_string += "/?authMechanism=MONGODB-X509"
-        pool = MongoClient(conn_info_string)
+        pool = pymongo.MongoClient(conn_info_string)
         return pool
