@@ -1,14 +1,20 @@
 # -*- coding: utf-8 -*-
-# author:chao.yy
-# email:yuyc@ishangqi.com
-# date:2022/2/17 2:45 下午
-# Copyright (C) 2022 The lesscode Team
-
-import aioredis
-import redis
+import importlib
 
 from lesscode.db.base_connection_pool import BaseConnectionPool
 
+redis = None
+aioredis = None
+try:
+    redis = importlib.import_module("redis")
+except ImportError as e:
+    raise Exception(f"redis is not exist,run:pip install redis==4.1.4")
+
+try:
+    aioredis = importlib.import_module("aioredis")
+except ImportError as e:
+    raise Exception(f"aioredis is not exist,run:pip install aioredis==2.0.1")
+
 
 class RedisPool(BaseConnectionPool):
     """
