@@ -1,11 +1,24 @@
+import importlib
 import math
 import os
 
 import tornado.options
-from filechunkio import FileChunkIO
-from ks3.connection import Connection
-from ks3.key import Key
-from ks3.prefix import Prefix
+
+ks3_connection = None
+ks3_key = None
+ks3_prefix = None
+try:
+    ks3_connection = importlib.import_module("ks3.connection")
+    ks3_key = importlib.import_module("ks3.key")
+    ks3_prefix = importlib.import_module("ks3.prefix")
+except ImportError as e:
+    raise Exception(f"ks3sdk is not exist,run:pip install ks3sdk==1.5.0")
+
+filechunkio = None
+try:
+    filechunkio = importlib.import_module("filechunkio")
+except ImportError as e:
+    raise Exception(f"filechunkio is not exist,run:pip install filechunkio==1.8")
 
 
 class Ks3Oss:
@@ -19,7 +32,7 @@ class Ks3Oss:
         bucket_name = kwargs.pop("bucket_name", None)
         if bucket_name is None:
             bucket_name = tornado.options.options.ks3_connect_config.get("bucket_name")
-        self.client = Connection(**kwargs)
+        self.client = ks3_connection.Connection(**kwargs)
         if bucket_name is not None:
             self.instance = self.client.get_bucket(bucket_name)
         else:
@@ -96,17 +109,17 @@ class Ks3Oss:
         files = list()
         dirs = list()
         for k in keys:
-            if isinstance(k, Key):
+            if isinstance(k, ks3_key.Key):
                 files.append(k.name)
-            elif isinstance(k, Prefix):
+            elif isinstance(k, ks3_prefix.Prefix):
                 dirs.append(k.name)
 
         for p in dirs:
             keys = self.instance.list(prefix=p, delimiter=delimiter, **kwargs)
             for k in keys:
-                if isinstance(k, Key):
+                if isinstance(k, ks3_key.Key):
                     files.append(k.name)
-                elif isinstance(k, Prefix):
+                elif isinstance(k, ks3_prefix.Prefix):
                     dirs.append(k.name)
         return dirs, files
 
@@ -146,7 +159,7 @@ class Ks3Oss:
         for i in range(chunk_count):
             offset = chunk_size * i
             bytes = min(chunk_size, file_size - offset)
-            with FileChunkIO(file_size, 'r', offset=offset, bytes=bytes) as fp:
+            with filechunkio.FileChunkIO(file_size, 'r', offset=offset, bytes=bytes) as fp:
                 mp.upload_part_from_file(fp, part_num=i + 1)
         ret = mp.complete_upload()
         return ret
