@@ -1,11 +1,10 @@
+import importlib
 import json
 import random
 
 import aiohttp
-import nacos
 import tornado.options
 import requests
-import py_eureka_client.eureka_client as eureka_client
 from lesscode.web.status_code import StatusCode
 
 from lesscode.web.business_exception import BusinessException
@@ -176,8 +175,13 @@ def eureka_request(path="", return_type="json", method="GET", data=None, app_nam
             kwargs.update({"headers": {
                 "Content-Type": "application/json"
             }})
-    res = eureka_client.do_service(app_name=app_name, service=path, return_type=return_type, method=method, data=data,
-                                   **kwargs)
+    try:
+        eureka_client = importlib.import_module("py_eureka_client.eureka_client")
+    except ImportError as e:
+        raise Exception(f"py-eureka-client is not exist,run:pip install py-eureka-client==0.11.3")
+    res = eureka_client.eureka_client.do_service(app_name=app_name, service=path, return_type=return_type,
+                                                 method=method, data=data,
+                                                 **kwargs)
     if return_type == "json" and not pack:
         if not pack:
             if res.get("status") == "00000":
@@ -222,6 +226,10 @@ def eureka_post(path="", data=None, return_type="json", app_name="DATA_SERVICE",
 
 def nacos_service_instance(service_name, namespace, clusters=None, group_name=None):
     server_addresses = tornado.options.options.nacos_config.get("server_addresses")
+    try:
+        nacos = importlib.import_module("nacos")
+    except ImportError as e:
+        raise Exception(f"nacos-sdk-python is not exist,run:pip install nacos-sdk-python==0.1.8")
     client = nacos.NacosClient(server_addresses=server_addresses, namespace=namespace)
     service = client.list_naming_instance(service_name=service_name, clusters=clusters, group_name=group_name,
                                           healthy_only=True)
