@@ -1,9 +1,6 @@
 # -*- coding: utf-8 -*-
-# author:chao.yy
-# email:yuyc@ishangqi.com
-# date:2021/11/11 8:06 下午
-# Copyright (C) 2021 The lesscode Team
 import asyncio
+import importlib
 import os
 import sys
 import logging
@@ -12,7 +9,6 @@ import traceback
 import tornado.web
 import tornado.ioloop
 import tornado.httpserver
-from apscheduler.schedulers.tornado import TornadoScheduler
 from tornado.log import LogFormatter as TornadoLogFormatter  # 避免命名歧义，设置了别名
 from tornado.options import options, define
 from typing import Optional
@@ -47,7 +43,7 @@ define("running_env", default="local", type=str, help="运行环境")
 define("request_type", default="request", type=str, help="请求类型")
 define("db", default=SQLAlchemy(), type=SQLAlchemy, help="SqlAlchemy")
 define("ks3_connect_config", default={}, type=dict, help="金山对象存储连接配置")
-define("scheduler", default=None, type=TornadoScheduler, help="Tornado任务调度")
+define("scheduler", default=None, type=object, help="Tornado任务调度")
 define("scheduler_config", default={}, type=dict, help="Tornado任务调度配置")
 define("nacos_config", default={}, type=dict, help="nacos配置")
 define("restful_handler", default=[], type=list, help="restful handler")
@@ -203,11 +199,15 @@ class WebServer:
                 __import__("{}.{}".format(pkg_name, handler_name.replace(".py", "")))
 
     def init_scheduler(self):
-        options.scheduler = TornadoScheduler(gconfig=options.scheduler_config.get("config", {}),
-                                             **options.scheduler_config.get("options", {}))
+        try:
+            tornado_scheduler = importlib.import_module("apscheduler.schedulers.tornado")
+        except ImportError as e:
+            raise Exception(f"apscheduler is not exist,run:pip install apscheduler==3.9.1")
+        options.scheduler = tornado_scheduler.TornadoScheduler(gconfig=options.scheduler_config.get("config", {}),
+                                                               **options.scheduler_config.get("options", {}))
         options.scheduler.start()
         logging.info('[Scheduler Init]APScheduler has been started')
-        if options.scheduler_config.get("enable") and options.task_list:
+        if options.task_list:
             for task in options.task_list:
                 if isinstance(task, dict):
                     task_func = task.get("func")
